//                                                                  
// Copyright  2013 Lidor Systems.
// All Rights Reserved.
//
// This SOFTWARE is provided "AS IS", WITHOUT WARRANTY OF ANY KIND.
// either express or implied.                        
//

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace IntegralUI_WinForms_Samples
{
    public partial class Form1 : Form
    {
        #region Initialization
        public Form1()
        {
            InitializeComponent();

            CreateLabelContent();

            InitList();
        }

        private void CreateLabelContent()
        {
            String content = "<div style=\"font:Verdana,9,r\"><p>By default only text is shown in column's header. In this sample we are showing how to place image to column header and place it in different positions:<br></br>";
            content += "   - Image is placed before header text<br></br>";
            content += "   - Image is placed imediatelly after header text<br></br>";
            content += "   - Image is placed after header text and it is aligned to the right side<br></br>";
            content += "   - Only image is placed in header<br></br>";
            content += "   - Image is placed above header text<br></br></p>";
            content += "<p>To create above examples we are using built-in support for &lt;img&gt; tag which allows image to be placed in custom positions.</p><br></br>";
            content += "<p><table width=\"100%\" cellpadding=\"5\"><tr><td width=\"100%\" style=\"align:middleright;textcolor:DarkRed;hovertextcolor:Red\"><a href=\"www.lidorsystems.com/support/articles/winforms/listview/\">More Info ...</a></td></tr></table></p>";
            content += "</div>";

            this.labelInfo.Content = content;
        }

        private void labelInfo_ContentObjectClicked(object sender, LidorSystems.IntegralUI.ObjectClickEventArgs e)
        {
            if (e.Object is LinkLabel)
                System.Diagnostics.Process.Start((e.Object as LinkLabel).Links[0].LinkData.ToString());
        }

        private void InitList()
        {
            this.listView1.SuspendUpdate();
            this.listView1.Columns.Clear();
            this.listView1.Items.Clear();

            LidorSystems.IntegralUI.Lists.ListViewColumn column = null;
            for (int j = 0; j < 5; j++)
            {
                column = new LidorSystems.IntegralUI.Lists.ListViewColumn("Header " + j.ToString(), "Footer " + j.ToString());
                column.Width = 100;

                this.listView1.Columns.Add(column);
            }


            LidorSystems.IntegralUI.Lists.ListViewItem item = null;
            LidorSystems.IntegralUI.Lists.ListViewSubItem subItem = null;

            for (int i = 0; i < 100; i++)
            {
                item = new LidorSystems.IntegralUI.Lists.ListViewItem("Item " + i.ToString());

                for (int j = 0; j < this.listView1.Columns.Count; j++)
                {
                    subItem = new LidorSystems.IntegralUI.Lists.ListViewSubItem("Item " + i.ToString() + j.ToString());
                    item.SubItems.Add(subItem);
                }

                this.listView1.Items.Add(item);
            }

            this.listView1.ResumeUpdate();
        }
        #endregion

        #region Update
        private void btnUpdate_Click(object sender, EventArgs e)
        {
            LidorSystems.IntegralUI.Lists.ListViewColumn column = null;

            for (int j = 0; j < this.listView1.Columns.Count; j++)
            {
                column = this.listView1.Columns[j];

                // Use ImageIndex property to place image before text
                if (rbImageBeforeText.Checked)
                {
                    column.ImageIndex = j;
                }
                // Use <img> tag to place image after text
                else if (rbTextBeforeImage.Checked)
                {
                    column.HeaderContent = "<div>" + column.HeaderText + " <img index=\"" + j.ToString() + "\"></img></div>";
                }
                // Use <img> tag to place image after text and align it on right side
                else if (rbImageOnRight.Checked)
                {
                    column.HeaderContent = "<div><table width=\"100%\"><tr><td width=\"100%\">" + column.HeaderText + "</td><td style=\"align:middleright\"><img index=\"" + j.ToString() + "\"></img></td></tr></table></div>";
                    column.WordWrap = true;
                }
                // Use <img> tag to add only image to column header and align it to the center
                else if (rbOnlyImage.Checked)
                {
                    column.HeaderContent = "<div><table width=\"100%\"><tr><td width=\"100%\" style=\"align:middlecenter\"><img src=\"../../../Demo/favorites.ico\"></img></td></tr></table></div>";
                    column.WordWrap = true;
                }
                // Use <img> tag to place image above text and align both to the center
                else if (rbImageAboveText.Checked)
                {
                    column.HeaderContent = "<div><table width=\"100%\" style=\"align:middlecenter\"><tr><td width=\"100%\"><img src=\"../../../Demo/pc.ico\"></img></td></tr><tr><td>" + column.HeaderText + "</td></tr></table></div>";
                    column.WordWrap = true;
                }
                // By default column header doesn't contain image
                else
                {
                    column.ImageIndex = -1;
                    column.HeaderContent = String.Empty;
                }
            }
        }
        #endregion
    }
}